#ifndef DINVERDCCORE_HEADERS
#define DINVERDCCORE_HEADERS

// All headers of DinverDCCore library

#include "AutocorrTarget.h"
#include "BottomValueCondition.h"
#include "DCModelInfo.h"
#include "DCReportBlock.h"
#include "DinverDCCoreDLLExport.h"
#include "DispersionTarget.h"
#include "EllipticityPeakTarget.h"
#include "Forward.h"
#include "GradientProfile.h"
#include "GroundParameter.h"
#include "LinearProfile.h"
#include "MagnetoTelluricTarget.h"
#include "ModalCurveTarget.h"
#include "ModalStorageReader.h"
#include "Param3DGroundModel.h"
#include "ParamGroundModel.h"
#include "ParamLayer.h"
#include "ParamProfile.h"
#include "PoissonCondition.h"
#include "PowerLawProfile.h"
#include "RefractionTarget.h"
#include "Target.h"
#include "TargetList.h"
#include "TargetList2D.h"
#include "UniformProfile.h"

#ifndef GP_EXPLICIT_LIBRARY_NAMESPACE
using namespace DinverDCCore;
#endif

#endif // DINVERDCCORE_HEADERS
